@@ -3,11 +3,11 @@ Package for data anonymization of different data types
 such as tabular, text, images and sound. 
 '''
 
-__version__ =  "0.1.9"
+__version__ =  "0.2.1"
 
 # Check if all dependencies have been installed
 
-hard_dependencies = ("faker", "pandas", "numpy")
+hard_dependencies = ("faker", "pandas", "numpy", "cv2")
 missing_dependencies = []
 
 for dependency in hard_dependencies:
@@ -22,7 +22,6 @@ if missing_dependencies:
     )
 del hard_dependencies, dependency, missing_dependencies
 
-
 from anonympy import pandas
 from anonympy import images
 from anonympy import sound 
